@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: PostDataChecker.h 2096 2006-11-26 08:43:57Z svn $
+ * $Id: PostDataChecker.h 2264 2006-12-14 14:25:43Z svn $
  *****************************************************************************/
 
 #ifndef POST_DATA_CHECKER_H
@@ -47,11 +47,15 @@ class PostDataChecker: public Uncopyable
 public:
     static void validate_uitem(apr_pool_t *pool, apr_off_t file_size,
                                apr_time_t  mtime, const char *file_name,
-                               const char *file_mime, const char *file_digest,
+                               const char **file_mime, const char *file_digest,
                                const char *remove_pass,
                                const char *download_pass,
                                const char **comment);
+private:
+    static const char HTML_EXT[];
+
     static void validate_file_name(const char *file_name);
+    static void validate_file_ext(const char *file_ext);
 };
 
 #endif
