@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemList.h 2173 2006-12-06 16:12:56Z svn $
+ * $Id: UploadItemList.h 2255 2006-12-13 09:05:01Z svn $
  *****************************************************************************/
 
 #ifndef UPLOAD_HEADER_LIST_H
@@ -33,6 +33,7 @@
 #include <cstdlib>
 
 #include "apr_shm.h"
+#include "apr_atomic.h"
 
 #include "UploadItem.h"
 #include "Uncopyable.h"
@@ -81,15 +82,15 @@ public:
     };
     apr_size_t size() const
     {
-        return *header_list_size_;
+        return header_list_size_;
     };
     apr_off_t get_total_file_size() const
     {
-        return *total_file_size_;
+        return total_file_size_;
     };
     bool is_full(apr_off_t file_size) const
     {
-        return (static_cast<apr_uint64_t>(*total_file_size_ + file_size) >
+        return (static_cast<apr_uint64_t>(total_file_size_ + file_size) >
                 max_file_size_) ||
             (size() == max_list_size_);
     };
@@ -145,8 +146,8 @@ private:
     static void dump_date(apr_pool_t *pool, apr_time_t time);
 
     UploadItem::header_t *header_list_;
-    apr_size_t *header_list_size_;
-    apr_off_t *total_file_size_;
+    apr_size_t header_list_size_;
+    apr_off_t total_file_size_;
     apr_uint64_t max_file_size_;
     apr_size_t max_list_size_;
 };
