@@ -68,6 +68,13 @@ function clearTimer()
     }
 }
 
+function setProgresssInfo(text)
+{
+    if (state != STATE_ERROR) {
+        progressInfo.innerHTML = text;
+    }
+}
+
 function updateProgress()
 {
     var progress;
@@ -78,7 +85,7 @@ function updateProgress()
         if (++failCount > 5) {
             clearTimer();
         }
-        progressInfo.innerHTML = 'Server Busy.';
+        setProgresssInfo('Server Busy.');
         return;
     } else {
         failCount = 0;
@@ -88,16 +95,12 @@ function updateProgress()
 
     if (progress.isFinish) {
         clearTimer();
-        progressInfo.innerHTML = 'Upload Succeeded!';
+        setProgresssInfo('Upload Succeeded!');
         setInterval('location.reload(true)', 2000);
         return;
     }
-    
-    if (state == STATE_ERROR) {
-        return;
-    }
 
-    progressInfo.innerHTML = getProgressMessage(progress);
+    setProgresssInfo(getProgressMessage(progress));
 }
 
 function getResponseDocument()
