@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: Auxiliary.cpp 2144 2006-11-29 14:54:20Z svn $
+ * $Id: Auxiliary.cpp 2263 2006-12-14 13:55:27Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -47,7 +47,7 @@
 
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: Auxiliary.cpp 2144 2006-11-29 14:54:20Z svn $");
+SOURCE_INFO_ADD("$Id: Auxiliary.cpp 2263 2006-12-14 13:55:27Z svn $");
 
 void init_atomic(apr_pool_t *pool)
 {
@@ -175,12 +175,21 @@ apr_size_t atosize(const char *s)
 const char *get_file_ext(const char *file_name)
 {
     const char *file_ext;
+    apr_size_t file_name_length;
 
-    for (file_ext = file_name+strlen(file_name); file_ext != file_name;
+    file_name_length = strlen(file_name);
+    if (file_name_length == 0 ) {
+        return "";
+    }
+
+    for (file_ext = file_name+file_name_length-1; file_ext != file_name;
          file_ext--) {
         if (*file_ext == '.') {
             return ++file_ext;
         }
+        if (!isalpha(static_cast<unsigned char>(*file_ext))) {
+            return "";
+        }
     }
 
     return file_ext;
